#[non_exhaustive]pub enum ClaimError {
CounterOverflow {
row_id: RowId,
},
EntropyUnavailable {
source: Error,
},
Serialization {
detail: String,
},
MigrationMismatch {
detail: String,
},
Sql {
operation: &'static str,
source: Error,
},
Transient {
operation: &'static str,
kind: TransientKind,
source: Error,
},
}Expand description
Errors returned while selecting and claiming a batch of events.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CounterOverflow
The delivery attempt counter cannot be incremented safely.
The operating system could not provide claim-token entropy.
Serialization
A database value could not be reconstructed as a valid domain value.
MigrationMismatch
The installed schema does not satisfy this adapter’s migration contract.
Sql
A non-transient SQL operation failed.
Fields
Transient
A SQL operation failed with a retryable PostgreSQL condition.