#[non_exhaustive]pub enum EnqueueError {
IdempotencyConflict {
existing_row_id: RowId,
},
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
Sql {
operation: &'static str,
source: Error,
},
Transient {
operation: &'static str,
kind: TransientKind,
source: Error,
},
}Expand description
Errors returned while enqueueing an event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdempotencyConflict
The immutable event identity already exists with different content.
MigrationMismatch
The installed schema does not satisfy this adapter’s migration contract.
Serialization
A database value could not be reconstructed as a valid domain value.
Sql
A non-transient SQL operation failed.
Fields
Transient
A SQL operation failed with a retryable PostgreSQL condition.