#[non_exhaustive]pub enum FinalizeError {
NotFound,
StateConflict {
row_id: RowId,
},
InvalidTimestamp {
source: ValidationError,
},
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
Sql {
operation: &'static str,
source: Error,
},
Transient {
operation: &'static str,
kind: TransientKind,
source: Error,
},
}Expand description
Errors returned by the migration-only delivery finalizer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
The requested event row does not exist.
StateConflict
The delivery row is not in the canonical imported pending state.
InvalidTimestamp
The supplied authoritative timestamp is invalid.
Fields

source: ValidationErrorThe timestamp validation failure from the domain type.
MigrationMismatch
The installed schema does not satisfy this adapter’s migration contract.
Serialization
A database value could not be reconstructed as a valid domain value.
Sql
A non-transient SQL operation failed.
Fields
Transient
A SQL operation failed with a retryable PostgreSQL condition.