#[non_exhaustive]pub enum ImportError {
IdentityConflict {
existing_row_id: RowId,
},
ImportConflict {
existing_row_id: RowId,
},
InvalidState {
source: ValidationError,
},
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
Sql {
operation: &'static str,
source: Error,
},
Transient {
operation: &'static str,
kind: TransientKind,
source: Error,
},
}Expand description
Errors returned by the migration-only importer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdentityConflict
The immutable event identity conflicts with an existing row.
ImportConflict
The imported delivery state conflicts with an existing row.
InvalidState
The supplied legacy delivery state is invalid.
Fields

source: ValidationErrorThe validation failure from the domain state.
MigrationMismatch
The installed schema does not satisfy this adapter’s migration contract.
Serialization
A database value could not be reconstructed as a valid domain value.
Sql
A non-transient SQL operation failed.
Fields
Transient
A SQL operation failed with a retryable PostgreSQL condition.