#[non_exhaustive]pub enum MutationError {
NotFound,
IllegalTransition {
state: DeliveryState,
},
LostClaim,
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
Sql {
operation: &'static str,
source: Error,
},
Transient {
operation: &'static str,
kind: TransientKind,
source: Error,
},
}Expand description
Errors returned by fenced post-claim mutations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
The requested event row does not exist.
IllegalTransition
The current delivery state cannot perform this mutation.
Fields

state: DeliveryStateThe delivery state that rejected the mutation.
LostClaim
The claim token is stale or the lease has expired.
MigrationMismatch
The installed schema does not satisfy this adapter’s migration contract.
Serialization
A database value could not be reconstructed as a valid domain value.
Sql
A non-transient SQL operation failed.
Fields
Transient
A SQL operation failed with a retryable PostgreSQL condition.