pub async fn release(
pool: &PgPool,
row_id: RowId,
claim_token: &ClaimToken,
delay: Delay,
) -> Result<(), MutationError>Expand description
Returns one current, unexpired claim to pending after a delay.
pub async fn release(
pool: &PgPool,
row_id: RowId,
claim_token: &ClaimToken,
delay: Delay,
) -> Result<(), MutationError>Returns one current, unexpired claim to pending after a delay.