check_schema

Function check_schema 

pub async fn check_schema(pool: &PgPool) -> Result<(), SchemaError>
Verifies the tables and all columns required by schema version 2.

Errors

Returns an error for an unsupported backend, missing or incompatible migration markers, tables, constraints or indexes, or failed catalog reads.