pub async fn check_schema(pool: &PgPool) -> Result<(), SchemaError>Expand description
Verifies the tables and all columns required by schema version 1.
pub async fn check_schema(pool: &PgPool) -> Result<(), SchemaError>Verifies the tables and all columns required by schema version 1.