pub async fn enqueue<'c>(
transaction: &mut Transaction<'c, Postgres>,
event: NewEvent,
) -> Result<EnqueueOutcome, EnqueueError>Expand description
Inserts an event and its pending delivery in the supplied caller transaction.
The transaction’s search_path must resolve to a namespace containing an
accepted Dovecote schema. Any database and namespace with the shipped
migration is valid; this operation does not bind itself to a prior
crate::check_schema call. The marker and domain tables are validated in
the caller transaction before any write, then unqualified table names are
used for the remainder of the operation.